#include <p16f690.inc>
	GLOBAL SCP_Config
SCP_SECTION0 CODE
SCP_Config
;
	;Load SPBRG with the correct count for 9600 baud
	BANKSEL SPBRG
	MOVLW .103
	MOVWF SPBRG
	;Load SPBRGH with the correct count for 9600 baud
	BANKSEL SPBRGH
	MOVLW 0
	MOVWF SPBRGH
;
	;BAUDCTL: BAUD RATE CONTROL REGISTER
	BANKSEL BAUDCTL
	;bit 7 ABDOVF: Auto-Baud Detect Overflow bit
		;Asynchronous mode:
		;1 = Auto-baud timer overflowed
		;0 = Auto-baud timer did not overflow
		;Synchronous mode:
		;Dont care
		;Note: Read Only
	;bit 6 RCIDL: Receive Idle Flag bit
		;Asynchronous mode:
		;1 = Receiver is Idle
		;0 = Start bit has been received and the receiver is receiving
		;Synchronous mode:
		;Dont care
		;Note: Read Only
	;bit 5 Unimplemented: Read as 0
	;bit 4 SCKP: Synchronous Clock Polarity Select bit
		;Asynchronous mode:
		;1 = Transmit inverted data to the RB7/TX/CK pin
		;0 = Transmit non-inverted data to the RB7/TX/CK pin
		;Synchronous mode:
		;1 = Data is clocked on rising edge of the clock
		;0 = Data is clocked on falling edge of the clock
	BCF BAUDCTL,SCKP
	;bit 3 BRG16: 16-bit Baud Rate Generator bit
		;1 = 16-bit Baud Rate Generator is used
		;0 = 8-bit Baud Rate Generator is used
	BSF BAUDCTL,BRG16
	;bit 2 Unimplemented: Read as 0
	;bit 1 WUE: Wake-up Enable bit
		;Asynchronous mode:
		;1 = Receiver is waiting for a falling edge. No character will be received byte RCIF will be set. WUE will
		;automatically clear after RCIF is set.
		;0 = Receiver is operating normally
		;Synchronous mode:
		;Dont care
	BCF BAUDCTL,WUE
	;bit 0 ABDEN: Auto-Baud Detect Enable bit
		;Asynchronous mode:
		;1 = Auto-Baud Detect mode is enabled (clears when auto-baud is complete)
		;0 = Auto-Baud Detect mode is disabled
		;Synchronous mode:
		;Dont care
	BCF BAUDCTL,ABDEN
;
	;TXSTA: Transmit Status and Control Register
	BANKSEL TXSTA
	;bit 7 CSRC: Clock Source Select bit
		;Asynchronous mode
		;Dont care
		;Synchronous mode
		;1 = Master mode (Clock generated internally from BRG)
		;0 = Slave mode (Clock from external source)
	BCF TXSTA,CSRC
	;bit 6 TX9: 9-bit Transmit Enable bit
		;1 = Selects 9-bit transmission
		;0 = Selects 8-bit transmission
	BCF TXSTA,TX9
	;bit 5 TXEN: Transmit Enable bit
		;1 = Transmit enabled
		;0 = Transmit disabled
		;Note: SREN/CREN overrides TXEN in SYNC mode.
	BSF TXSTA,TXEN
	;bit 4 SYNC: USART Mode Select bit
		;1 = Synchronous mode
		;0 = Asynchronous mode
	BCF TXSTA,SYNC
	;bit 3 SENDB: Send Break Character bit
		;Asynchronous mode:
		;1 = Send Sync Break on next transmission (cleared by hardware upon completion)
		;0 = Sync Break transmission completed
		;Synchronous mode:
		;Dont care
	BCF TXSTA,SENB
	;bit 2 BRGH: High Baud Rate Select bit
		;Asynchronous mode
		;1 = High speed
		;0 = Low speed
		;Synchronous mode
		;Unused in this mode
	BSF TXSTA,BRGH
	;bit 1 TRMT: Transmit Shift Register Status bit
		;1 = TSR empty
		;0 = TSR full
		;Note: Read Only
	;bit 0 TX9D: 9th bit of transmit data. Can be parity bit.
	BCF TXSTA,TX9D
;
	;RCSTA: RECEIVE STATUS AND CONTROL REGISTER
	BANKSEL RCSTA
	;bit 7 SPEN: Serial Port Enable bit
		;1 = Serial port enabled (configures RX/DT and TX/CK pins as serial port pins)
		;0 = Serial port disabled (held in Reset)
	BSF RCSTA,SPEN
	;bit 6 RX9: 9-bit Receive Enable bit
		;1 = Selects 9-bit reception
		;0 = Selects 8-bit reception
	BCF RCSTA,RX9
	;bit 5 SREN: Single Receive Enable bit
		;Asynchronous mode:
		;Dont care
		;Synchronous mode  Master:
		;1 = Enables single receive
		;0 = Disables single receive
		;This bit is cleared after reception is complete.
		;Synchronous mode  Slave
		;Dont care
	BCF RCSTA,SREN
	;bit 4 CREN: Continuous Receive Enable bit
		;Asynchronous mode:
		;1 = Enables receiver
		;0 = Disables receiver
		;Synchronous mode:
		;1 = Enables continuous receive until enable bit CREN is cleared (CREN overrides SREN)
		;0 = Disables continuous receive
	BSF RCSTA,CREN
	;bit 3 ADDEN: Address Detect Enable bit
		;Asynchronous mode 9-bit (RX9 = 1):
		;1 = Enables address detection, enable interrupt and load the receive buffer when RSR<8> is set
		;0 = Disables address detection, all bytes are received and ninth bit can be used as parity bit
		;Asynchronous mode 8-bit (RX9 = 0):
		;Dont care
		;Note: Read Only
	BCF RCSTA,ADDEN
	;bit 2 FERR: Framing Error bit
		;1 = Framing error (can be updated by reading RCREG register and receive next valid byte)
		;0 = No framing error
		;Note: Read Only
	;bit 1 OERR: Overrun Error bit
		;1 = Overrun error (can be cleared by clearing bit CREN)
		;0 = No overrun error
		;Note: Read Only
	;bit 0 RX9D: Ninth bit of Received Data
		;This can be address/data bit or a parity bit and must be calculated by user firmware.
		;Note: Read Only
;
	RETURN
;
	END